==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/ownrmat/bean/OwnEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.assist.ownrmat.bean.OwnDetailEntity;
/**
 * 自有材料摊销
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proownrmat_own")
public class OwnEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 摊销单位
    @TableField(value="org_code")
    private String orgCode; // 摊销单位编码
    @TableField(value="org_name")
    private String orgName; // 摊销单位名称
    @TableField(value="amortization_cycle")
    private String amortizationCycle; // 摊销周期
    @TableField(value="amortization_mny_tax")
    private BigDecimal amortizationMnyTax; // 摊销金额(含税)
    @TableField(value="amortization_mny")
    private BigDecimal amortizationMny; // 摊销金额(无税)
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="processing_date")
    private Date processingDate; // 办理日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="category_name")
    private String categoryName; // 材料分类名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="amortization_method")
    private Integer amortizationMethod; // 摊销方法,0-年平均法，1-录入
    @TableField(value="last_date")
    private String lastDate; // 上次摊销周期
    @TableField(value="effect_time")
    private Date effectTime; // 单据生效时间

    
    @TableField(exist=false)
    @SubEntity(serviceName="ownDetailService",pidName = "ownId")
    private List<OwnDetailEntity> ownDetailList = new ArrayList<>(); // 自有材料摊销-清单


    public Date getEffectTime() {
        return effectTime;
    }

    public void setEffectTime(Date effectTime) {
        this.effectTime = effectTime;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getLastDate() {
        return lastDate;
    }

    public void setLastDate(String lastDate) {
        this.lastDate = lastDate;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAmortizationCycle() {
        return amortizationCycle;
    }

    public void setAmortizationCycle(String amortizationCycle) {
        this.amortizationCycle = amortizationCycle;
    }
    public BigDecimal getAmortizationMnyTax() {
        return amortizationMnyTax;
    }

    public void setAmortizationMnyTax(BigDecimal amortizationMnyTax) {
        this.amortizationMnyTax = amortizationMnyTax;
    }
    public BigDecimal getAmortizationMny() {
        return amortizationMny;
    }

    public void setAmortizationMny(BigDecimal amortizationMny) {
        this.amortizationMny = amortizationMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Date getProcessingDate() {
        return processingDate;
    }

    public void setProcessingDate(Date processingDate) {
        this.processingDate = processingDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getAmortizationMethod() {
        return amortizationMethod;
    }

    public void setAmortizationMethod(Integer amortizationMethod) {
        this.amortizationMethod = amortizationMethod;
    }
    

    public List<OwnDetailEntity> getOwnDetailList() {
        return ownDetailList;
    }

    public void setOwnDetailList(List<OwnDetailEntity> ownDetailList) {
        this.ownDetailList = ownDetailList;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220408.080827-57-sources.jar: com/ejianc/business/assist/ownrmat/bean/OwnEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.assist.ownrmat.bean.OwnDetailEntity;
/**
 * 自有材料摊销
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistownrmat_own")
public class OwnEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 摊销单位
    @TableField(value="org_code")
    private String orgCode; // 摊销单位编码
    @TableField(value="org_name")
    private String orgName; // 摊销单位名称
    @TableField(value="amortization_cycle")
    private String amortizationCycle; // 摊销周期
    @TableField(value="amortization_mny_tax")
    private BigDecimal amortizationMnyTax; // 摊销金额(含税)
    @TableField(value="amortization_mny")
    private BigDecimal amortizationMny; // 摊销金额(无税)
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="dept_id")
    private Long deptId; // 经办部门
    @TableField(value="dept_name")
    private String deptName; // 经办部门名称
    @TableField(value="processing_date")
    private Date processingDate; // 办理日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="category_name")
    private String categoryName; // 材料分类名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="amortization_method")
    private Integer amortizationMethod; // 摊销方法,0-年平均法，1-录入
    @TableField(value="last_date")
    private String lastDate; // 上次摊销周期
    @TableField(value="effect_time")
    private Date effectTime; // 单据生效时间

    
    @TableField(exist=false)
    @SubEntity(serviceName="ownDetailService",pidName = "ownId")
    private List<OwnDetailEntity> ownDetailList = new ArrayList<>(); // 自有材料摊销-清单


    public Date getEffectTime() {
        return effectTime;
    }

    public void setEffectTime(Date effectTime) {
        this.effectTime = effectTime;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getLastDate() {
        return lastDate;
    }

    public void setLastDate(String lastDate) {
        this.lastDate = lastDate;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAmortizationCycle() {
        return amortizationCycle;
    }

    public void setAmortizationCycle(String amortizationCycle) {
        this.amortizationCycle = amortizationCycle;
    }
    public BigDecimal getAmortizationMnyTax() {
        return amortizationMnyTax;
    }

    public void setAmortizationMnyTax(BigDecimal amortizationMnyTax) {
        this.amortizationMnyTax = amortizationMnyTax;
    }
    public BigDecimal getAmortizationMny() {
        return amortizationMny;
    }

    public void setAmortizationMny(BigDecimal amortizationMny) {
        this.amortizationMny = amortizationMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public Date getProcessingDate() {
        return processingDate;
    }

    public void setProcessingDate(Date processingDate) {
        this.processingDate = processingDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getAmortizationMethod() {
        return amortizationMethod;
    }

    public void setAmortizationMethod(Integer amortizationMethod) {
        this.amortizationMethod = amortizationMethod;
    }
    

    public List<OwnDetailEntity> getOwnDetailList() {
        return ownDetailList;
    }

    public void setOwnDetailList(List<OwnDetailEntity> ownDetailList) {
        this.ownDetailList = ownDetailList;
    }
}
